summaryrefslogtreecommitdiffstats
path: root/power
diff options
context:
space:
mode:
authorTodd Poynor <toddpoynor@google.com>2012-04-27 17:07:20 -0700
committerTodd Poynor <toddpoynor@google.com>2012-04-27 17:07:20 -0700
commit7497b21f5520a1d4f8788aba50592aef5a481231 (patch)
treefd018acdef4aba603d03342847b7422f7eb0a6be /power
parent9d224c27f681d726e2c4d769e5829d2f17e7c414 (diff)
downloaddevice_samsung_tuna-7497b21f5520a1d4f8788aba50592aef5a481231.zip
device_samsung_tuna-7497b21f5520a1d4f8788aba50592aef5a481231.tar.gz
device_samsung_tuna-7497b21f5520a1d4f8788aba50592aef5a481231.tar.bz2
tuna: Power HAL: Enable touchscreen input boost
Change-Id: I8d296e36222a45599edf7d3cab48a9aa8aae7bd7
Diffstat (limited to 'power')
-rw-r--r--power/power_tuna.c3
1 files changed, 2 insertions, 1 deletions
diff --git a/power/power_tuna.c b/power/power_tuna.c
index 63ccfe8..0613bff 100644
--- a/power/power_tuna.c
+++ b/power/power_tuna.c
@@ -68,7 +68,7 @@ static void tuna_power_init(struct power_module *module)
/*
* cpufreq interactive governor: timer 20ms, min sample 100ms,
* hispeed 700MHz at load 40%
*/
sysfs_write("/sys/devices/system/cpu/cpufreq/interactive/timer_rate",
@@ -81,6 +81,7 @@ static void tuna_power_init(struct power_module *module)
"40");
sysfs_write("/sys/devices/system/cpu/cpufreq/interactive/above_hispeed_delay",
"100000");
+ sysfs_write("/sys/devices/system/cpu/cpufreq/interactive/input_boost", "1");
}
static void tuna_power_set_interactive(struct power_module *module, int on)
@@ -68,7 +68,7 @@ static void tuna_power_init(struct power_module *module)
/*
* cpufreq interactive governor: timer 20ms, min sample 100ms,
- * hispeed 700MHz at load 40%
+ * hispeed 700MHz at load 40%, input boost enabled.
*/
sysfs_write("/sys/devices/system/cpu/cpufreq/interactive/timer_rate",